netapp_ontap.models.nvme_subsystem_host_subsystem API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.nvme_subsystem_host_subsystem`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class NvmeSubsystemHostSubsystemSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the NvmeSubsystemHostSubsystem object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `links GET`

    The links field of the nvme_subsystem_host_subsystem.

  `uuid GET`

    The unique identifier of the NVMe subsystem.

    Example: 1cd8a442-86d1-11e0-ae1c-123478563412